==> nextcloud-14.0.1.tgz: nextcloud/apps/theming/l10n/da.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Indlæser forhåndsvisning...",
    "Saved" : "Gemt",
    "Admin" : "Admin",
    "a safe home for all your data" : "Et sikket hjem til alt dit data",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Webadressen er for lang",
    "The given slogan is too long" : "Sloganet er for langt",
    "The given color is invalid" : "Farven er ikke gyldig",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "No file uploaded" : "Ingen fil uploadet",
    "Unsupported image type" : "Ikke-understøttet billede format",
    "Theming" : "Temaer",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming gør det muligt nemt at tilpasse udseendet på din installation og understøttede klienter. Dette vil være synlig for alle brugere.",
    "Name" : "Navn",
    "Reset to default" : "Nulstil",
    "Slogan" : "Slogan",
    "Color" : "Farve",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nyt logo",
    "Login image" : "Login billede",
    "Upload new login background" : "Upload nyt login billede",
    "Remove background image" : "Fjern baggrundsbillede",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer Imagemagick PHP udvidelsen med SVG support for automatisk at genererer favikoner baseret på the uploadede logo og farver.",
    "You are already using a custom theme" : "Du bruger allerede et brugerdefineret tema",
    "reset to default" : "nulstil til standardindstillinger ",
    "Web address" : "Web adresse",
    "Web address https://…" : "Web adresse http://...",
    "There is no error, the file uploaded with success" : "Der skete ingen fejl, filen blev succesfuldt uploadet",
    "The uploaded file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "Failed to write file to disk." : "Fejl ved skrivning af fil til disk.",
    "A PHP extension stopped the file upload." : "En PHP-udvidelse stoppede file uploaden."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/theming/l10n/da.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Indlæser forhåndsvisning...",
    "Saved" : "Gemt",
    "Admin" : "Admin",
    "a safe home for all your data" : "Et sikket hjem til alt dit data",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Webadressen er for lang",
    "The given slogan is too long" : "Sloganet er for langt",
    "The given color is invalid" : "Farven er ikke gyldig",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "No file uploaded" : "Ingen fil uploadet",
    "Unsupported image type" : "Ikke-understøttet billede format",
    "Theming" : "Temaer",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temaer gør det muligt nemt at tilpasse udseendet på din installation og understøttede klienter. Dette vil være synlig for alle brugere.",
    "Name" : "Navn",
    "Reset to default" : "Nulstil",
    "Slogan" : "Slogan",
    "Color" : "Farve",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nyt logo",
    "Login image" : "Login billede",
    "Upload new login background" : "Upload nyt login billede",
    "Remove background image" : "Fjern baggrundsbillede",
    "Advanced options" : "Avancerede indstillinger",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer Imagemagick PHP udvidelsen med SVG support for automatisk at genererer favikoner baseret på the uploadede logo og farver.",
    "There is no error, the file uploaded with success" : "Der skete ingen fejl, filen blev succesfuldt uploadet",
    "The uploaded file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "Failed to write file to disk." : "Fejl ved skrivning af fil til disk.",
    "A PHP extension stopped the file upload." : "En PHP-udvidelse stoppede file uploaden.",
    "You are already using a custom theme" : "Du bruger allerede et brugerdefineret tema",
    "Web address https://…" : "Web adresse http://..."
},
"nplurals=2; plural=(n != 1);");
